@@ -5,7 +5,6 @@
 # https://opensource.org/licenses/BSD-3-Clause
 
 from __future__ import print_function
-from inspect import getargspec
 import os
 import sys
 
@@ -23,8 +22,17 @@ def import_module(possible_modules, needed_module):
             count -= 1
             if count == 0:
                 raise
-
-from IPython.core.debugger import Pdb, BdbQuit_excepthook
+try:
+    # IPython 5.0 and newer
+    from IPython.terminal.debugger import TerminalPdb as Pdb
+    from IPython.core.debugger import BdbQuit_excepthook
+    from IPython.terminal.interactiveshell import TerminalInteractiveShell
+    # Let IPython decide about which debugger class to use
+    # This is especially important for tools that fiddle with stdout
+    debugger_cls = TerminalInteractiveShell().debugger_cls
+except ImportError:
+    from IPython.core.debugger import Pdb, BdbQuit_excepthook
+    debugger_cls = Pdb
 
 possible_modules = ['IPython.terminal.ipapp',           # Newer IPython
                     'IPython.frontend.terminal.ipapp']  # Older IPython
@@ -64,12 +72,11 @@ else:
 
 def_exec_lines = [line + '\n' for line in ipapp.exec_lines]
 
-
 def _init_pdb(context=3):
-    if 'context' in getargspec(Pdb.__init__)[0]:
-        p = Pdb(def_colors, context=context)
-    else:
-        p = Pdb(def_colors)
+    try:
+        p = debugger_cls(def_colors, context=context)
+    except TypeError:
+        p = debugger_cls(def_colors)
     p.rcLines += def_exec_lines
     return p
 
